@@ -1,15 +1,26 @@
+# ----------------------------------------------------------------------
+# Curses::UI::PopupBox
+#
+# (c) 2001-2002 by Maurice Makaay. All rights reserved.
+# This file is part of Curses::UI. Curses::UI is free software.
+# You can redistribute it and/or modify it under the same terms
+# as perl itself.
+#
+# e-mail: maurice@gitaar.net
+# ----------------------------------------------------------------------
+
 package Curses::UI::PopupBox;
 
 use strict;
 use Curses;
 use Curses::UI::Common;
-use Curses::UI::Frame;
+use Curses::UI::Widget;
 use Curses::UI::ListBox;
 use Curses::UI::Label;
 
 use vars qw($VERSION @ISA);
 $VERSION = '1.0.0';
-@ISA = qw(Curses::UI::Frame Curses::UI::Common);
+@ISA = qw(Curses::UI::Widget Curses::UI::Common);
 
 my %routines = (
         'return'   	=> 'RETURN',
@@ -37,9 +48,6 @@ sub new ()
 {
 	my $class = shift;
 
-	my %myroutines = %routines;
-	my %mybindings = %bindings;
-
 	my %args = (
 		-parent		 => undef,	# the parent window
 		-width		 => undef,	# the width of the checkbox
@@ -49,8 +57,8 @@ sub new ()
 		-labels		 => {},		# labels for the values
 		-selected	 => undef,	# the current selected value
 
-		-bindings	 => \%mybindings,
-		-routines	 => \%myroutines,
+		-bindings	 => {%bindings},
+		-routines	 => {%routines},
 
 		@_,
 	
@@ -94,7 +102,7 @@ sub layout()
 
 	$this->SUPER::layout();
 
-	# Create the label on the frame.
+	# Create the label on the widget.
 	my $label = new Curses::UI::Label(
 		-parent   => $this,
 		-x        => 0,
@@ -150,7 +158,7 @@ sub draw(;$)
 	my $this = shift;
 	my $no_doupdate = shift || 0;
 		
-	# Draw the frame.
+	# Draw the widget.
 	$this->SUPER::draw(1);
 
 	# Get the selected label.
