@@ -1,9 +1,20 @@
+# ----------------------------------------------------------------------
+# Curses::UI::RadioButtonBox
+#
+# (c) 2001-2002 by Maurice Makaay. All rights reserved.
+# This file is part of Curses::UI. Curses::UI is free software.
+# You can redistribute it and/or modify it under the same terms
+# as perl itself.
+#
+# e-mail: maurice@gitaar.net
+# ----------------------------------------------------------------------
+
 package Curses::UI::RadioButtonBox;
 
 use strict;
 use Curses;
 use Curses::UI::ListBox;
-use Curses::UI::Frame;
+use Curses::UI::Widget;
 
 use vars qw($VERSION @ISA);
 @ISA = qw(Curses::UI::ListBox);
